--[[
NAME
    route_co2
NOTES
    A 3D plot for CO2 concentrations along a ship route.
    Refer to animate.lua on animation of the window.
]]

require("plot_3d")
plot = plot_3d.new(600, 500)
plot:scale(.5, .5, .4)
plot:xaxis{range = {130, 170}, smooth = true,
         tickmarks = {130, 10, 0}, ticklength = 1.5,
         label = "Longitude (deg-E)"}
plot:yaxis{range = {-10, 50}, smooth = true,
         tickmarks = {-10, 10, 0}, ticklength = 1.5,
         label = "Latitude (deg-N)"}
plot:zaxis{range = {370, 400}, smooth = true,
         tickmarks = {375, 5, 0}, ticklength = 1.5,
         label = "CO<sub>2</sub> (ppm)"}

-- plot CO2 and route

require("read_text")
arr = read_text("./examples/route_co2.txt", " ")

line, xyz = zeGrf.new("line", "vertex")
line:set{vertex = xyz, type = "lines", color = {1, 0, 0, 1}}
plot:add(line)

n = arr:size()
for k = 0, n-1 do
    x = arr:getele(k, 5)
    y = arr:getele(k, 4)
    z = arr:getele(k, 6)
    xyz:add(x, y, z)
    xyz:add(x, y, 370)
end

-- plot coastlines

line, xyz = zeGrf.new("line", "vertex")
line:set{vertex = xyz, type = "lines", color = {0, 0, 1, 1}, solid = 1.5}
plot:add(line)

bio = zeUtl.new("bio")
bio:open("./data/gshhs_l.b")                 -- you must have this file
bio:gshhs("land", 131, 170, -9, 50, arr)
arr:insert(2, 370)
xyz:add(arr)

-- the frame

line, xyz = zeGrf.new("line", "vertex")
line:set{vertex = xyz, type = "strip", solid = 1.5}
plot:add(line)
xyz:add(130, 50, 370)
xyz:add(170, 50, 370)
xyz:add(170, -10, 370)

-- render image

plot:translate(20, 40, 0)
plot:animate()
